RulerPicker class

Inheritance

Constructors

RulerPicker({Key? key, required double initNumber, required double height, required dynamic callbackDouble(double), dynamic callbackInt(int)?, MoonRulerLinesType linesType = MoonRulerLinesType.lineWithLabel, double borderWidth = 1, Color pickedBarColor = Colors.blueAccent, Color barColor = Colors.blue, double longVerticalLineHeightRatio = 0.8, double shortVerticalLineHeightRatio = 0.72, double selectedVerticalLineHeightRatio = 1, double resistance = 1, double acceleration = 1, int maxNumber = 100, int minNumber = 0, TextStyle labelTextStyle = const TextStyle(fontSize: 10, color: Colors.blue), double rulerBetweenAlignWidth = 8})
const

Properties

acceleration double
final
barColor Color
final
borderWidth double
final
callbackDouble → dynamic Function(double)
final
callbackInt → dynamic Function(int)?
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
initNumber double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelTextStyle TextStyle
final
linesType MoonRulerLinesType
final
longVerticalLineHeightRatio double
final
maxNumber int
final
minNumber int
final
pickedBarColor Color
final
resistance double
final
rulerBetweenAlignWidth double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedVerticalLineHeightRatio double
final
shortVerticalLineHeightRatio double
final

Methods

createElement() LeafRenderObjectElement
RenderObjectWidgets always inflate to a RenderObjectElement subclass.
inherited
createRenderObject(BuildContext context) RenderObject
Creates an instance of the RenderObject class that this RenderObjectWidget represents, using the configuration described by this RenderObjectWidget.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didUnmountRenderObject(covariant RenderObject renderObject) → void
This method is called when a RenderObject that was previously associated with this widget is removed from the render tree. The provided RenderObject will be of the same type as the one created by this widget's createRenderObject method.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
updateRenderObject(BuildContext context, covariant _RulerPickerRenderBox renderObject) → void
Copies the configuration described by this RenderObjectWidget to the given RenderObject, which will be of the same type as returned by this object's createRenderObject.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited